@@ -1,3 +1,5 @@
+from typing import TypeVar, Callable, Dict, Type, Any
+
 import attr
 import copy
 import math
@@ -6,13 +8,14 @@ import traceback
 from barril._util.types_ import CheckType
 from oop_ext.foundation.singleton import Singleton
 
-# Contains the registry for all the avaiable unit types.
+# Contains the registry for all the available unit types.
 __all__ = [
     "CategoryInfo",
     "InvalidOperationError",
     "InvalidQuantityTypeError",
     "InvalidUnitError",
     "UnitDatabase",
+    "UnitInfo",
     "UnitsError",
 ]
 
@@ -187,6 +190,10 @@ class CategoryInfo:
     caption = attr.ib(default="")
 
 
+T = TypeVar("T")
+ConversionFunc = Callable[["UnitDatabase", str, str, str, T], T]
+
+
 class UnitDatabase(Singleton):
     """
     Registry with all the available quantity types and units that represent the physical units.
@@ -283,7 +290,7 @@ class UnitDatabase(Singleton):
     #
     # dict of class supported -> conversion function
     # see RegisterAdditionalConversionType
-    _additional_conversions = {}
+    _additional_conversions: Dict[Type, ConversionFunc] = {}
 
     def __init__(self, default_singleton=False):
         """
@@ -1072,7 +1079,7 @@ class UnitDatabase(Singleton):
         return ret
 
     @classmethod
-    def RegisterAdditionalConversionType(cls, class_, func):
+    def RegisterAdditionalConversionType(cls, class_: Type, func: ConversionFunc) -> None:
         """
         This function may be used to register conversions for additional classes, not originally
         treated (e.g.: IGridFunction)
@@ -1205,7 +1212,12 @@ class UnitDatabase(Singleton):
             category_to_unit_and_exp1 = copy.deepcopy(quantity1.GetCategoryToUnitAndExps())
             category_to_unit_and_exp2 = copy.deepcopy(quantity2.GetCategoryToUnitAndExps())
 
-            category_to_unit_and_exp1, category_to_unit_and_exp2, value1, value2 = self._MatchQuantities(
+            (
+                category_to_unit_and_exp1,
+                category_to_unit_and_exp2,
+                value1,
+                value2,
+            ) = self._MatchQuantities(
                 category_to_unit_and_exp1, category_to_unit_and_exp2, value1, value2
             )
 
@@ -1330,7 +1342,12 @@ class UnitDatabase(Singleton):
         category_to_unit_and_exp1 = quantity1.GetCategoryToUnitAndExpsCopy()
         category_to_unit_and_exp2 = quantity2.GetCategoryToUnitAndExpsCopy()
 
-        category_to_unit_and_exp1, category_to_unit_and_exp2, value1, value2 = self._MatchQuantities(
+        (
+            category_to_unit_and_exp1,
+            category_to_unit_and_exp2,
+            value1,
+            value2,
+        ) = self._MatchQuantities(
             category_to_unit_and_exp1, category_to_unit_and_exp2, value1, value2
         )
 
