@@ -1,30 +1,15 @@
 import weakref
-from collections import OrderedDict
 from copy import deepcopy
-from typing import Dict
-from typing import List
-from typing import Mapping
-from typing import Optional
-from typing import Sequence
-from typing import Set
-from typing import Tuple
-from typing import Type
-from typing import TYPE_CHECKING
 
 from oop_ext.foundation import callback
 from oop_ext.foundation.decorators import Override
+from collections import OrderedDict
 from oop_ext.foundation.singleton import Singleton
 from oop_ext.interface import AssertImplements
 
 from .unit_database import UnitDatabase
 from .unit_system import UnitSystem
 from .unit_system_interface import IUnitSystem
-from barril.units import AbstractValueWithQuantityObject
-from barril.units import IQuantity
-
-
-if TYPE_CHECKING:
-    from barril.units import Scalar
 
 
 class NoTemplateError(RuntimeError):
@@ -32,7 +17,7 @@ class NoTemplateError(RuntimeError):
     Error raised when trying to create a new unit system and no template was defined.
     """
 
-    def __init__(self) -> None:
+    def __init__(self):
         msg = "Error creating unit system. There is no template defined."
         RuntimeError.__init__(self, msg)
 
@@ -43,9 +28,9 @@ class InvalidTemplateError(RuntimeError):
     match the given template
     """
 
-    def __init__(self, invalid_unit_system_ids: Optional[List[Optional[str]]] = None):
+    def __init__(self, invalid_unit_system_ids=None):
         """
-        :param invalid_unit_system_ids:
+        :param iterable(unicode) invalid_unit_system_ids:
             The ids of the unit system that do not match a given template
         """
         if invalid_unit_system_ids:
@@ -63,7 +48,7 @@ class UnitSystemCategoriesError(KeyError):
     template.
     """
 
-    def __init__(self, default_categories: List[str], current_categories: List[str]):
+    def __init__(self, default_categories, current_categories):
         msg = "Error creating new unit system. The default categories are %s but %s were defined."
         KeyError.__init__(self, msg % (default_categories, current_categories))
 
@@ -73,9 +58,9 @@ class UnitSystemIDError(KeyError):
     Error raised when trying to create a new unit system given an already used ID.
     """
 
-    def __init__(self, id: str):
-        msg = f"Error creating new unit system. The ID {id} is already in use."
-        KeyError.__init__(self, msg)
+    def __init__(self, id):
+        msg = "Error creating new unit system. The ID %s is already in use."
+        KeyError.__init__(self, msg % (id))
 
 
 class UnitSystemManager(Singleton):
@@ -83,44 +68,46 @@ class UnitSystemManager(Singleton):
     A service that manages the unit systems. It handles the unit system objects creation and
     selection.
 
-    :ivar _object_refs:
-        Set of weakref for all objects which represents a value+unit.
+    :ivar list _object_refs:
+        List of weakref for all objects which represents a value+unit.
 
+    :type current: IUnitSystem instance
     :ivar current:
         The current unit system.
 
-    :ivar on_current:
+    :ivar Callback on_current:
         Callback called when the current unit system changes (the unit system is given as parameter).
 
-    :ivar on_unit_changed:
+    :ivar Callback on_unit_changed:
         Callback called when the the unit of a category changes (the category and unit is given as
         parameter).
 
+    :type _unit_systems: dict(unicode, IUnitSystem instance)
     :ivar _unit_systems:
         A dict that holds the available unit systems.
     """
 
-    def __init__(self) -> None:
-        # list with objects with a unit associated with it.
-        self._object_refs: Set[_IdentityWrap] = set()
+    def __init__(self):
+        # list with valueable objects with a unit associated with
+        self._object_refs = set()
 
         # someone would want to listen to changes in the current unit system
-        self.on_current = callback.Callback1[IUnitSystem]()
+        self.on_current = callback.Callback()
 
         # someone would want to listen to changes in unit system categories unit.
-        self.on_unit_changed = callback.Callback2[str, Optional[str]]()
+        self.on_unit_changed = callback.Callback()
 
         # the current unit system which is being used by the application
-        self._current: Optional[IUnitSystem] = None
+        self._current = None
 
         # container for registered unit systems (strong references)
-        self._unit_systems: OrderedDict[str, IUnitSystem] = OrderedDict()
+        self._unit_systems = OrderedDict()
 
         # unit system template.
-        self._unit_system_template: Optional[IUnitSystem] = None
+        self._unit_system_template = None
 
         # default unit system class.
-        self._default_unit_system_class: Type[IUnitSystem] = UnitSystem
+        self._default_unit_system_class = UnitSystem
 
         # This unit system is returned when no current unit system is selected
         self.__null_unit_system = UnitSystem(
@@ -128,31 +115,33 @@ class UnitSystemManager(Singleton):
         )
 
     @Override(Singleton.ResetInstance)
-    def ResetInstance(self) -> None:
+    def ResetInstance(self):
         self.on_current.UnregisterAll()
         self.on_unit_changed.UnregisterAll()
 
-    def SetDefaultUnitSystemClass(self, class_: Type[IUnitSystem]) -> None:
+    def SetDefaultUnitSystemClass(self, class_):
         """
         Set the default unit system class.
 
+        :type class_: IUnitSystem class
         :param class_:
-            The unit system class that will be used when creating new unit systems.
+            The unit system class that wiil be used when creating new unit systems.
         """
         AssertImplements(class_, IUnitSystem)
         self._default_unit_system_class = class_
 
-    def SetTemplateUnitSystemByUnitsMapping(self, units_mapping: Dict[str, str]) -> None:
+    def SetTemplateUnitSystemByUnitsMapping(self, units_mapping):
         """
         Set the unit system template based on the given units mapping.
 
         This template will be used to validate new unit systems.
 
+        :type units_mapping: dict( unicode, unicode )
         :param units_mapping:
             A dict that maps each category to a related unit (which will be set as default).
             The valid categories are defined by the coilib50.units.UnitDatabase.
 
-        :raise: TemplateDefinedAfterUnitSystemError
+        @raise: TemplateDefinedAfterUnitSystemError
             See TemplateDefinedAfterUnitSystemError documentation.
         """
         template_categories = list(units_mapping.keys())
@@ -176,39 +165,34 @@ class UnitSystemManager(Singleton):
             "template", "Unit system template", units_mapping, True
         )
 
-    def GetUnitSystemTemplate(self) -> Optional[IUnitSystem]:
+    def GetUnitSystemTemplate(self):
         """
+        :rtype: IUnitSystem instance
         :returns:
             Return the template unit system.
         """
         return self._unit_system_template
 
-    def _CheckUnitSystemMapping(
-        self, units_mapping: Dict[str, str], required_categories: List[str]
-    ) -> bool:
+    def _CheckUnitSystemMapping(self, units_mapping, required_categories):
         """
         Checks if the given units mapping have a default unit for all required categories
 
+        :type units_mapping: dict( unicode, unicode )
         :param units_mapping units_mapping:
             A dict that maps each category to a related unit. the dict should contain mapping for
             each category defined in the template.
 
-        :param required_categories:
+        :param required_categoris list(unicode)
             The categories required in the given unit system.
         """
         required_categories_set = set(required_categories)
 
         current_categories = list(units_mapping.keys())
+        current_categories = set(current_categories)
 
-        return set(current_categories).issuperset(required_categories_set)
+        return current_categories.issuperset(required_categories_set)
 
-    def AddUnitSystem(
-        self,
-        id: str,
-        caption: str,
-        units_mapping: Optional[Dict[str, str]] = None,
-        read_only: bool = False,
-    ) -> IUnitSystem:
+    def AddUnitSystem(self, id, caption, units_mapping=None, read_only=False):
         """
         Create a new unit system based on the given parameters.
 
@@ -218,18 +202,19 @@ class UnitSystemManager(Singleton):
         It is expected that a unit system template is already set. The template will be used to
         validate the categories from the given units mapping.
 
-        :param id:
+        :param unicode id:
             The unique id of the unit system.
 
-        :param caption:
+        :param unicode caption:
             The user-friendly name of the unit system.
 
+        :type units_mapping: dict( unicode, unicode ) or None
         :param units_mapping:
             A dict that maps each category to a related unit (which will be set as default).
             The valid categories are defined by the coilib50.units.UnitDatabase.
             If None is given the units mapping from the template will be taken.
 
-        :param read_only:
+        :param bool read_only:
             Flag that sets the read-only state of the new unit system.
 
         :raises NoTemplateError:
@@ -241,6 +226,7 @@ class UnitSystemManager(Singleton):
         :raises UnitSystemCategoriesError:
             See UnitSystemCategoriesError documentation.
 
+        :rtype: IUnitSystem instance
         :returns:
             The created unit system.
         """
@@ -277,19 +263,19 @@ class UnitSystemManager(Singleton):
 
         return unit_system
 
-    def _CategoryUnitChange(self, category: str, unit: Optional[str]) -> None:
+    def _CategoryUnitChange(self, category, unit):
         """
         Triggers on_unit_changed callback when default unit change on a category in a unit system.
 
-        :param category:
+        :param unicode category:
             The changed category.
 
-        :param unit:
+        :param unicode unit:
             The new unit.
         """
         self.on_unit_changed(category, unit)
 
-    def RemoveUnitSystem(self, unit_system_id: str) -> None:
+    def RemoveUnitSystem(self, unit_system_id):
         """
         Remove the unit system with the given id.
 
@@ -299,7 +285,6 @@ class UnitSystemManager(Singleton):
         del self._unit_systems[unit_system_id]
 
         # If the current unit system was removed, set another system as current
-        assert self._current is not None
         if self._current.GetId() == unit_system_id:
             available = list(self.GetUnitSystems().values())
 
@@ -308,8 +293,9 @@ class UnitSystemManager(Singleton):
             else:
                 self.SetCurrent(None)
 
-    def GetUnitSystems(self) -> Dict[str, IUnitSystem]:
+    def GetUnitSystems(self):
         """
+        :rtype: dict{unicode, IUnitSystem instance)
         :returns:
             The dict containing all the registered unit systems indexed by their ids.
         """
@@ -317,10 +303,11 @@ class UnitSystemManager(Singleton):
 
     # Current --------------------------------------------------------------------------------------
 
-    def SetCurrent(self, unit_system: Optional[IUnitSystem]) -> None:
+    def SetCurrent(self, unit_system):
         """
         Sets a new current unit system, updating all registered objects. If None, no object is changed.
 
+        :type unit_system: IUnitSystem instance
         :param unit_system:
             The new current unit system.
         """
@@ -331,14 +318,14 @@ class UnitSystemManager(Singleton):
 
         if self._current is not None:
             self._current.on_default_unit.Register(self._CategoryUnitChange)
-            self.on_current(self._current)
+            self.on_current(unit_system)
         else:
             # Notifying that an empty unit system was set for the clients
             self.on_current(self.__null_unit_system)
 
         self.UpdateObjects()
 
-    def GetCurrent(self) -> IUnitSystem:
+    def GetCurrent(self):
         """
         Retrieves the unit system currently in use.
 
@@ -358,7 +345,7 @@ class UnitSystemManager(Singleton):
 
     # Objects --------------------------------------------------------------------------------------
 
-    def UpdateObjects(self) -> None:
+    def UpdateObjects(self):
         """
         Updates the units of all the registered objects. Also, remove dead objects from the list
         """
@@ -376,19 +363,49 @@ class UnitSystemManager(Singleton):
                     if unit is not None:
                         obj.unit = unit
 
-    def Register(self, obj: AbstractValueWithQuantityObject) -> None:
+    class IdentityWrap:
+        """
+        Helper class to remove an object from the unit system references.
+
+        It's used so that we create a wrapper that'll give the __hash__ and __eq__ based on
+        the object id.
+        """
+
+        __slots__ = ["unit_system", "ref"]
+
+        def __init__(self, obj, unit_system):
+            """
+            :param object obj:
+                The object we'll be wrapping.
+
+            :param UnitSystem unit_system:
+                The unit system with the tracked object.
+            """
+            self.unit_system = unit_system
+            self.ref = weakref.ref(obj, self._OnRefKilled)
+
+        def _OnRefKilled(self, ref):
+            """
+            Called when a reference to an object with a unit is killed.
+
+            :param weakref ref:
+                The weak-ref that was killed
+            """
+            self.unit_system._object_refs.remove(self)
+
+    def Register(self, obj):
         """
         Keeps a weak reference to the object in an internal list.
         Whatever change in the unit system will be propagated for all objects in the list.
 
-        :param obj:
+        :param AbstractValueWithQuantityObject obj:
             An object which represents a value associated with a unit.
 
         .. note:: This code should in general only be called from the constructor of an object to be
         tracked and only once (although adding an object more than once won't give any errors, it'll
         incur in more overhead because the object will be added more than once to the internal list).
         """
-        self._object_refs.add(_IdentityWrap(obj, self))
+        self._object_refs.add(self.IdentityWrap(obj, self))
         current = self._current
         if current is not None:
             # Update the object to match the current unit-system.
@@ -396,13 +413,14 @@ class UnitSystemManager(Singleton):
             if unit is not None:
                 obj.unit = unit
 
-    def GetUnitSystemById(self, id: str) -> IUnitSystem:
+    def GetUnitSystemById(self, id):
         """
         Returns the UnitSystem with the given id.
 
-        :param id:
+        :param unicode id:
             The wished unit system id.
 
+        :rtype: IUnitSystem instance
         :returns:
             The unit system with the given id.
 
@@ -414,10 +432,11 @@ class UnitSystemManager(Singleton):
         else:
             raise ValueError("No UnitSystem with id %r found" % id)
 
-    def GetNewId(self) -> str:
+    def GetNewId(self):
         """
         Returns an unit system id that is not being used.
 
+        :rtype: unicode
         :returns:
             The available id.
         """
@@ -429,25 +448,24 @@ class UnitSystemManager(Singleton):
             new_id = "%s %d" % ("system", count)
         return new_id
 
-    def ConvertToCurrent(
-        self, category: str, unit: str, value: float, unit_database: Optional[UnitDatabase] = None
-    ) -> Tuple[float, str]:
+    def ConvertToCurrent(self, category, unit, value, unit_database=None):
         """
         Converts the given value from the given unit to the default unit of the current unit system.
         If there is no current unit system, no conversion is performed.
 
-        :param category:
+        :param unicode category:
             The unit's category.
 
-        :param unit:
+        :param unicode unit:
             The source unit.
 
-        :param value:
+        :param float value:
             The value to convert.
 
-        :param unit_database:
+        :param UnitDatabase unit_database:
             The unit database to perform the conversion. If not given, use the singleton.
 
+        :rtype: (float, unicode)
         :returns:
             The pair (value, unit), containing the converted value and target unit. Note that
             if there is no current unit system, the returned value and unit are the same as
@@ -458,17 +476,18 @@ class UnitSystemManager(Singleton):
 
         current = self.current
         if current is None or current.GetDefaultUnit(category) is None:
-            return value, unit
+            return (value, unit)
 
         to_unit = current.GetDefaultUnit(category)
         converted_value = unit_database.Convert(category, unit, to_unit, value)
         return converted_value, to_unit
 
-    def GetCategoryDefaultUnit(self, category: str) -> Optional[str]:
+    def GetCategoryDefaultUnit(self, category):
         """
-        :param category:
+        :param unicode category:
             The category to obtain the default unit
 
+        :rtype: unicode or None
         :returns:
             The default unit to display the given category or None if there is no default unit set.
         """
@@ -483,16 +502,16 @@ class UnitSystemManager(Singleton):
 
         return result
 
-    def GetQuantityDefaultUnit(self, quantity: IQuantity) -> str:
+    def GetQuantityDefaultUnit(self, quantity):
         """
         Get the default unit to use with a given quantity. If there is any map explictly defined for
         the quantity category, then that map will be used. Otherwise we will use the quantity default
         unit.
 
-        :param quantity:
+        :param IQuantity quantity:
             The quantity to obtain the default unit
 
-        :return:
+        :return unicode
             The default unit to use with the given quantity
         """
         current_system = self.GetCurrent()
@@ -508,9 +527,7 @@ class UnitSystemManager(Singleton):
 
         return result
 
-    def ConvertScalarToCurrent(
-        self, scalar: "Scalar", unit_database: Optional[UnitDatabase] = None
-    ) -> "Scalar":
+    def ConvertScalarToCurrent(self, scalar, unit_database=None):
         """
         Same as ConvertToCurrent but receives and returns a scalar instead of category, unit and value
 
@@ -532,34 +549,3 @@ class UnitSystemManager(Singleton):
             scalar.GetCategory(), scalar.GetUnit(), scalar.GetValue(), unit_database
         )
         return Scalar(*ret_tuple)
-
-
-class _IdentityWrap:
-    """
-    Helper class to remove an object from the unit system references.
-
-    It's used so that we create a wrapper that'll give the __hash__ and __eq__ based on
-    the object id.
-    """
-
-    __slots__ = ["unit_system", "ref"]
-
-    def __init__(self, obj: AbstractValueWithQuantityObject, unit_system: UnitSystemManager):
-        """
-        :param obj:
-            The object we'll be wrapping.
-
-        :param unit_system:
-            The unit system manager with the tracked object.
-        """
-        self.unit_system = unit_system
-        self.ref = weakref.ref(obj, self._OnRefKilled)
-
-    def _OnRefKilled(self, ref: object) -> None:
-        """
-        Called when a reference to an object with a unit is killed.
-
-        :param ref:
-            The weak-ref that was killed
-        """
-        self.unit_system._object_refs.remove(self)
